@@ -34,11 +34,9 @@ class ItemEncoder:
 		if self.n_items == None :
 			self.n_items = len(list(set(items)))
 
-		item_set = list(set(items))
-		self.item_ids = [0] * self.n_items
-		self.item_ids[:len(item_set)] = item_set
+		self.item_ids = list(set(items))
 		item_id_to_idx = {}
-		for iid in item_set:
+		for iid in self.item_ids:
 			item_id_to_idx[iid] = self.item_ids.index(iid)
 
 		encoded = np.zeros((len(items), self.n_items*2))
@@ -216,29 +214,46 @@ class DKT(nn.Module):
 		return -np.mean(bce)
 
 	def influence_matrix(self):
+		matrix = self._conditional_predict_matrix()
+		matrix = y_ / np.sum(y_, axis=0)
+		return matrix
+
+	def _conditional_predict_matrix(self):
 		self.eval()
 		x = torch.zeros(size=(1, self.n_items, self.n_items*2)).to(self.device)
 		for n in range(self.n_items):
 			x[0, n, n] = 1
 
 		with torch.no_grad():
-			y_ = self(x)[0].detach().cpu().numpy()
+			return self(x)[0].detach().cpu().numpy()
 
-		matrix = y_ / np.sum(y_, axis=0)
-		return matrix
+	def graph(self, item_encoder, method='conditional', use_label=False, threshold=0.1):
+		if method == 'transition':
+			mat = item_encoder.transition_count.T
+			mat /= np.sum(mat, axis=0)
+			mat = mat.T
+		elif method == 'conditional':
+			cond = self._conditional_predict_matrix()
+			mat = item_encoder.transition_count.T
+			mat /= np.sum(mat, axis=0)
+			mat = mat.T * cond
+		else:
+			print('[Warning] Wrong method entered.')
+			return
 
-	def graph(self, item_encoder, threshold=0.1):
-		mat = item_encoder.transition_count.T
-		mat /= np.sum(mat, axis=0)
-		mat = mat.T
-		
 		edges = []
 		for i in range(self.n_items):
 			for j in range(self.n_items):
 				if i!=j and mat[i,j] >= threshold and mat[i,j] > mat[j,i]:
-					edges.append((i,j, mat[i,j]))
+					if use_label:
+						edges.append((item_encoder.item_ids[i], item_encoder.item_ids[j], mat[i,j]))
+					else:
+						edges.append((i,j, mat[i,j]))
 
-		print(edges)
 		g = nx.DiGraph()
+		if use_label:
+			g.add_nodes_from(item_encoder.item_ids)
+		else :
+			g.add_nodes_from(range(self.n_items))
 		g.add_weighted_edges_from(edges)
 		return g
\ No newline at end of file
